@@ -1,27 +1,29 @@
 /*
  * gamelist.c -- Functions to manage a gamelist
- * XBoard $Id: gamelist.c,v 1.8 1997/05/17 07:33:03 mann Exp $
  *
- * Copyright 1995 Free Software Foundation, Inc.
+ * Copyright 1995, 2009, 2010 Free Software Foundation, Inc.
+ *
+ * Enhancements Copyright 2005 Alessandro Scotti
  *
  * ------------------------------------------------------------------------
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU XBoard is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or (at
+ * your option) any later version.
+ *
+ * GNU XBoard is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- * ------------------------------------------------------------------------
- */
+ * along with this program. If not, see http://www.gnu.org/licenses/.  
+ *
+ *------------------------------------------------------------------------
+ ** See the file ChangeLog for a revision history.  */
 
-#include <config.h>
+#include "config.h"
 
 #include <stdio.h>
 #include <errno.h>
@@ -70,6 +72,7 @@ static void GameListDeleteGame(listGame)
 	if (listGame->gameInfo.resultDetails) free(listGame->gameInfo.resultDetails);
 	if (listGame->gameInfo.timeControl) free(listGame->gameInfo.timeControl);
 	if (listGame->gameInfo.extraTags) free(listGame->gameInfo.extraTags);
+        if (listGame->gameInfo.outOfBook) free(listGame->gameInfo.outOfBook);
 	ListNodeFree((ListNode *) listGame);
     }
 }
@@ -93,9 +96,6 @@ static void GameListFree(gameList)
 void GameListInitGameInfo(gameInfo)
     GameInfo *gameInfo;
 {
-  if (appData.debugMode)
-    fprintf(debugFP, "InitGameInfo\n");
-  
     gameInfo->event = NULL;
     gameInfo->site = NULL;
     gameInfo->date = NULL;
@@ -109,6 +109,9 @@ void GameListInitGameInfo(gameInfo)
     gameInfo->extraTags = NULL;
     gameInfo->whiteRating = -1; /* unknown */
     gameInfo->blackRating = -1; /* unknown */
+    gameInfo->variant = VariantNormal;
+    gameInfo->outOfBook = NULL;
+    gameInfo->resultDetails = NULL;
 }
 
 
@@ -153,15 +156,16 @@ int GameListBuild(f)
     ListGame *currentListGame = NULL;
     int error;
     int offset;
+    char lastComment[MSG_SIZ];
 
     GameListFree(&gameList);
     yynewfile(f);
     gameNumber = 0;
 
     lastStart = (ChessMove) 0;
-    yyskipmoves = TRUE;
+    yyskipmoves = FALSE;
     do {
-	yyboardindex = 1;
+        yyboardindex = 0;
 	offset = yyoffset();
 	cm = (ChessMove) yylex();
 	switch (cm) {
@@ -224,6 +228,33 @@ int GameListBuild(f)
 		}
 	    } while (cm == PGNTag || cm == Comment);
 	    break;
+	  case NormalMove:
+	    /* Allow the first game to start with an unnumbered move */
+	    yyskipmoves = TRUE;
+	    if (lastStart == (ChessMove) 0) {
+	      if ((error = GameListNewGame(&currentListGame))) {
+		rewind(f);
+		yyskipmoves = FALSE;
+		return(error);
+	      }
+	      currentListGame->number = ++gameNumber;
+	      currentListGame->offset = offset;
+	      lastStart = MoveNumberOne;
+	    }
+	    break;
+        case WhiteWins: // [HGM] rescom: save last comment as result details
+        case BlackWins:
+        case GameIsDrawn:
+        case GameUnfinished:
+	    if (currentListGame->gameInfo.resultDetails != NULL) {
+		free(currentListGame->gameInfo.resultDetails);
+	    }
+	    if(yy_text[0] == '{') { char *p;
+		strcpy(lastComment, yy_text+1);
+		if(p = strchr(lastComment, '}')) *p = 0;
+		currentListGame->gameInfo.resultDetails = StrSave(lastComment);
+	    }
+	    break;
 	  default:
 	    break;
 	}
@@ -253,9 +284,6 @@ int GameListBuild(f)
 void ClearGameInfo(gameInfo)
     GameInfo *gameInfo;
 {
-  if (appData.debugMode)
-    fprintf(debugFP, "ClearGameInfo\n");
-  
     if (gameInfo->event != NULL) {
 	free(gameInfo->event);
     }
@@ -286,12 +314,15 @@ void ClearGameInfo(gameInfo)
     if (gameInfo->extraTags != NULL) {
 	free(gameInfo->extraTags);
     }
-
+    if (gameInfo->outOfBook != NULL) {
+        free(gameInfo->outOfBook);
+    }
     GameListInitGameInfo(gameInfo);
 }
 
+/* [AS] Replaced by "dynamic" tag selection below */
 char *
-GameListLine(number, gameInfo)
+GameListLineOld(number, gameInfo)
      int number;
      GameInfo *gameInfo;
 {
@@ -300,10 +331,110 @@ GameListLine(number, gameInfo)
     char *white = gameInfo->white ? gameInfo->white : "?";
     char *black = gameInfo->black ? gameInfo->black : "?";
     char *date = gameInfo->date ? gameInfo->date : "?";
-    int len = 10 + strlen(event) + 3 + strlen(white) + 1 + 
-      strlen(black) + 3 + strlen(date) + 1;
+    int len = 10 + strlen(event) + 2 + strlen(white) + 1 + 
+      strlen(black) + 11 + strlen(date) + 1;
     char *ret = (char *) malloc(len);
-    sprintf(ret, "%d  %s / %s-%s / %s", number, event, white, black, date);
+    sprintf(ret, "%d. %s, %s-%s, %s, %s",
+	    number, event, white, black, PGNResult(gameInfo->result), date);
     return ret;
 }
 
+#define MAX_FIELD_LEN   80  /* To avoid overflowing the buffer */
+
+char * GameListLine( int number, GameInfo * gameInfo )
+{
+    char buffer[1024];
+    char * buf = buffer;
+    char * glt = appData.gameListTags;
+    
+    buf += sprintf( buffer, "%d.", number );
+
+    while( *glt != '\0' ) {
+        *buf++ = ' ';
+
+        switch( *glt ) {
+        case GLT_EVENT:
+            strncpy( buf, gameInfo->event ? gameInfo->event : "?", MAX_FIELD_LEN );
+            break;
+        case GLT_SITE:
+            strncpy( buf, gameInfo->site ? gameInfo->site : "?", MAX_FIELD_LEN );
+            break;
+        case GLT_DATE:
+            strncpy( buf, gameInfo->date ? gameInfo->date : "?", MAX_FIELD_LEN );
+            break;
+        case GLT_ROUND:
+            strncpy( buf, gameInfo->round ? gameInfo->round : "?", MAX_FIELD_LEN );
+            break;
+        case GLT_PLAYERS:
+            strncpy( buf, gameInfo->white ? gameInfo->white : "?", MAX_FIELD_LEN );
+            buf[ MAX_FIELD_LEN-1 ] = '\0';
+            buf += strlen( buf );
+            *buf++ = '-';
+            strncpy( buf, gameInfo->black ? gameInfo->black : "?", MAX_FIELD_LEN );
+            break;
+        case GLT_RESULT:
+            strcpy( buf, PGNResult(gameInfo->result) );
+            break;
+        case GLT_WHITE_ELO:
+            if( gameInfo->whiteRating > 0 )
+                sprintf( buf, "%d", gameInfo->whiteRating );
+            else
+                strcpy( buf, "?" );
+            break;
+        case GLT_BLACK_ELO:
+            if( gameInfo->blackRating > 0 )
+                sprintf( buf, "%d", gameInfo->blackRating );
+            else
+                strcpy( buf, "?" );
+            break;
+        case GLT_TIME_CONTROL:
+            strncpy( buf, gameInfo->timeControl ? gameInfo->timeControl : "?", MAX_FIELD_LEN );
+            break;
+        case GLT_VARIANT:
+            break;
+        case GLT_OUT_OF_BOOK:
+            strncpy( buf, gameInfo->outOfBook ? gameInfo->outOfBook : "?", MAX_FIELD_LEN );
+            break;
+        case GLT_RESULT_COMMENT:
+            strncpy( buf, gameInfo->resultDetails ? gameInfo->resultDetails : "res?", MAX_FIELD_LEN );
+            break;
+        default:
+            break;
+        }
+
+        buf[MAX_FIELD_LEN-1] = '\0';
+
+        buf += strlen( buf );
+
+        glt++;
+
+        if( *glt != '\0' ) {
+            *buf++ = ',';
+        }
+    }
+
+    *buf = '\0';
+
+    return strdup( buffer );
+}
+
+char * GameListLineFull( int number, GameInfo * gameInfo )
+{
+    char * event = gameInfo->event ? gameInfo->event : "?";
+    char * site = gameInfo->site ? gameInfo->site : "?";
+    char * white = gameInfo->white ? gameInfo->white : "?";
+    char * black = gameInfo->black ? gameInfo->black : "?";
+    char * round = gameInfo->round ? gameInfo->round : "?";
+    char * date = gameInfo->date ? gameInfo->date : "?";
+    char * oob = gameInfo->outOfBook ? gameInfo->outOfBook : "";
+    char * reason = gameInfo->resultDetails ? gameInfo->resultDetails : "";
+    
+    int len = 64 + strlen(event) + strlen(site) + strlen(white) + strlen(black) + strlen(date) + strlen(oob) + strlen(reason);
+
+    char *ret = (char *) malloc(len);
+
+    sprintf(ret, "%d, \"%s\", \"%s\", \"%s\", \"%s\", \"%s\", \"%s\", \"%s\", \"%s\", \"%s\"",
+	number, event, site, round, white, black, PGNResult(gameInfo->result), reason, date, oob );
+
+    return ret;
+}
