@@ -2,6 +2,7 @@
 // Microsoft Developer Studio generated include file.
 // Used by winboard.rc
 //
+#define MANIFEST_RESOURCE_ID              1
 #define IDM_NewGame                     100
 #define IDM_LoadGame                    101
 #define IDM_SaveGame                    102
@@ -21,6 +22,7 @@
 #define IDM_Pause                       116
 #define IDM_CallFlag                    117
 #define IDM_Draw                        118
+#define IDM_SaveDiagram                 119
 #define IDM_Abort                       120
 #define IDM_Adjourn                     122
 #define IDM_Resign                      124
@@ -55,6 +57,10 @@
 #define IDM_PasteGame                   181
 #define IDM_CopyPosition                182
 #define IDM_PastePosition               183
+#define IDM_NewVariant                  184  
+#define IDM_TypeInName                  185  
+#define IDM_MachineBoth                 186  
+#define IDM_MuteSounds                  187
 #define OPT_TCtext1                     202
 #define OPT_TCTime                      203
 #define OPT_TCtext2                     204
@@ -81,16 +87,39 @@
 #define OPT_TCInc                       407
 #define OPT_TCitext3                    408
 #define OPT_TCTime2                     409
+#define OPT_TCOdds1                     410
+#define OPT_TCOdds2                     411
 #define DLG_PremoveOptions              450
 #define DLG_GeneralOptions              453
 #define DLG_IcsOptions                  454
 #define DLG_BoardOptions                455
 #define DLG_Fonts                       456
+#define DLG_NewGameFRC                  457
+#define DLG_GameListOptions             458
+#define DLG_MoveHistory                 459
+#define DLG_EvalGraph                   461
+#define DLG_EngineOutput                463
+#define DLG_EnginePlayOptions           464
+#define IDI_WHITE_14                    466
+#define IDI_BLACK_14                    467
+#define DLG_OptionsUCI                  467
+#define IDI_PONDER_14                   468
+#define IDI_TRANS_14                    469
+#define IDI_CLOCK_14                    470
+#define IDI_UNKNOWN_14                  471
+#define IDI_BALOON_14                   472
+#define IDI_ANALYZE_14                  473
+#define IDI_ANALYZE2_14                 474
 #define DLG_Promotion                   500
 #define PB_Queen                        502
 #define PB_Rook                         503
 #define PB_Bishop                       504
 #define PB_Knight                       505
+#define PB_Chancellor                   506 /* [HGM] Capablanca pieces */
+#define PB_Archbishop                   507
+#define IDC_Yes                         520
+#define IDC_No                          521
+#define IDC_Centaur                     522
 #define EP_White                        600
 #define EP_WhitePawn                    601
 #define EP_WhiteKnight                  602
@@ -112,6 +141,22 @@
 #define DP_Bishop                       618
 #define DP_Rook                         619
 #define DP_Queen                        620
+
+#define EP_WhiteCardinal                630
+#define EP_WhiteMarshall                631
+#define EP_WhiteAlfil                   632
+#define EP_WhiteCannon                  633
+#define EP_WhiteFerz                    634
+#define EP_WhiteWazir                   635
+#define EP_BlackCardinal                640
+#define EP_BlackMarshall                641
+#define EP_BlackAlfil                   642
+#define EP_BlackCannon                  643
+#define EP_BlackFerz                    644
+#define EP_BlackWazir                   645
+#define EP_Promote                      650
+#define EP_Demote                       651
+
 #define DLG_LoadOptions                 700
 #define DLG_SaveOptions                 800
 #define OPT_PGN                         802
@@ -151,6 +196,10 @@
 #define DLG_ConsoleRich                 1022
 #define IDC_EDIT1                       1023
 #define OPT_DarkSquareColor             1023
+#define IDC_GameListFilter              1023
+#define IDC_NFG_Edit                    1023
+#define IDC_EpDrawMoveCount             1023
+#define IDC_PolyglotDir                 1023
 #define OPT_ConsoleText                 1024
 #define OPT_LightSquareColor            1024
 #define OPT_CommandInput                1025
@@ -167,11 +216,14 @@
 #define OPT_SampleDarkSquare            1030
 #define OPT_PremoveWhiteText            1031
 #define IDC_EDIT2                       1032
+#define IDC_EpAdjudicationThreshold     1032
+#define IDC_HashSize                    1032
 #define OPT_ConsoleInput                1033
 #define OPT_AdditionalOptions           1034
 #define OPT_PremoveBlackText            1035
 #define OPT_ErrorText                   1036
 #define OPT_IcsAlarmTime                1037
+#define OPT_Name                        1038
 #define DLG_Console                     1100
 #define DLG_PromotionKing               1102
 #define DLG_Colorize                    1106
@@ -181,6 +233,7 @@
 #define DLG_Sound                       1127
 #define DLG_IndexNumber                 1149
 #define DLG_TypeInMove                  1151
+#define DLG_TypeInName                  1152
 #define OPT_IndexNumberOld              1155
 #define IDM_Rematch                     1203
 #define IDA_PAGEUP                      1216
@@ -214,10 +267,22 @@
 #define IDM_GeneralOptions              1299
 #define IDM_BoardOptions                1300
 #define IDM_Fonts                       1301
+#define IDM_UserAdjudication_White      1302
+#define IDM_UserAdjudication_Black      1303
+#define IDM_UserAdjudication_Draw       1304
+#define IDM_NewGameFRC                  1305
+#define IDM_GameListOptions             1306
 #define PB_King                         1307
+#define IDM_ShowMoveHistory             1307
+#define IDM_PasteAny                    1309
+#define IDM_ShowEvalGraph               1310
+#define IDM_CopyGameListToClipboard     1311
 #define OPT_Bold                        1312
+#define IDM_ShowEngineOutput            1312
 #define OPT_Italic                      1313
+#define IDM_EnginePlayOptions           1313
 #define OPT_Underline                   1314
+#define IDM_OptionsUCI                  1314
 #define OPT_Strikeout                   1315
 #define OPT_ChooseColor                 1316
 #define OPT_Sample                      1318
@@ -338,8 +403,111 @@
 #define OPT_ChooseCommentsFont          1417
 #define OPT_ChooseConsoleFont           1418
 #define OPT_DefaultFonts                1419
+#define OPT_ChooseMoveHistoryFont       1420
 #define OPT_AutoRaiseBoard              1421
+#define OPT_SampleMoveHistoryFont       1421
 #define OPT_ShowButtonBar               1422
+#define OPT_MessageFont6                1422
+#define OPT_SaveExtPGN                  1423
+#define OPT_HideThinkFromHuman          1424
+#define IDC_GameListDoFilter            1425
+#define IDC_NFG_Random                  1426
+#define IDC_NFG_Label                   1427
+#define IDC_GameListTags                1428
+#define IDC_GLT                         1429
+#define IDC_GLT_Up                      1430
+#define IDC_GLT_Down                    1431
+#define IDC_GLT_Restore                 1432
+#define IDC_GLT_Default                 1433
+#define IDC_GLT_RestoreTo               1434
+#define IDC_MoveHistory                 1435
+#define OPT_OutOfBookInfo               1436
+#define OPT_ExtraInfoInMoveHistory      1437
+#define OPT_HighlightMoveArrow          1438
+#define IDC_BUTTON1                     1440
+#define IDC_BrowseForPolyglotDir        1440
+#define IDC_BrowseForEGTB               1441
+#define IDC_BrowseForBook               1442
+#define IDC_EngineMemo1                 1443
+#define IDC_EngineMemo2                 1444
+#define IDC_EngineLabel1                1445
+#define IDC_EngineLabel2                1446
+#define IDC_EpShowThinking              1447
+#define IDC_EpHideThinkingHuman         1448
+#define IDC_EpPonder                    1449
+#define IDC_EpPeriodicUpdates           1450
+#define IDC_Engine1_NPS                 1451
+#define IDC_Engine2_NPS                 1452
+#define IDC_Color1                      1459
+#define IDC_Color2                      1460
+#define IDC_StateIcon1                  1461
+#define IDC_StateData1                  1462
+#define IDC_StateData2                  1463
+#define IDC_StateIcon2                  1464
+#define IDC_PathToEGTB                  1466
+#define IDC_SizeOfEGTB                  1467
+#define IDC_BookFile                    1469
+#define IDC_UseBook                     1470
+#define IDC_OwnBook1                    1471
+#define IDC_OwnBook2                    1472
+#define IDC_Cores                       1473
+#define DLG_NewVariant                  1500
+#define OPT_VariantGothic               1501
+#define OPT_VariantCrazyhouse           1502
+#define OPT_VariantBughouse             1503
+#define OPT_VariantCourier              1504
+#define OPT_VariantShatranj             1505
+#define OPT_VariantShogi                1506
+#define OPT_VariantXiangqi              1507
+#define OPT_VariantCapablanca           1508
+#define OPT_VariantTwoKings             1509
+#define OPT_VariantKnightmate           1510
+#define OPT_VariantLosers               1511
+#define OPT_VariantSuicide              1512
+#define OPT_VariantAtomic               1513
+#define OPT_VariantNormal               1514
+#define OPT_VariantFairy                1515
+#define OPT_VariantFRC                  1516
+#define OPT_VariantCylinder             1517
+#define OPT_VariantFalcon               1518
+#define OPT_VariantCRC                  1519
+#define OPT_VariantBerolina             1520
+#define OPT_VariantSuper                1521
+#define OPT_VariantJanus                1522
+#define OPT_VariantWildcastle           1523
+#define OPT_VariantNocastle             1524
+#define OPT_VariantGiveaway             1525
+#define OPT_Variant3Check               1526
+#define OPT_VariantGreat                1527
+#define OPT_VariantTwilight             1528
+#define OPT_VariantMakruk               1529
+#define IDC_Files                       1550
+#define IDC_Ranks                       1551
+#define IDC_Holdings                    1552
+#define IDC_TestClaims                  1600
+#define IDC_DetectMates                 1601
+#define IDC_MaterialDraws               1602
+#define IDC_TrivialDraws                1603
+#define IDC_RuleMoves                   1604
+#define IDC_DrawRepeats                 1605
+#define IDC_ScoreAbs1                   1606
+#define IDC_ScoreAbs2                   1607
+#define IDM_FlipClock                   1700
+#define OPT_AllWhite                    1701
+#define OPT_UpsideDown                  1702
+#define DLG_Chat			1720
+#define IDC_Change			1721
+#define IDC_ChatPartner			1722
+#define IDC_ChatMemo			1723
+#define OPT_ChatInput			1724
+#define IDC_Clear			1725
+#define IDC_Send			1726
+#define IDM_NewChat			1727
+#define IDC_SPECIFY_ENG_STATIC          1814
+#define IDC_SPECIFY_SERVER_STATIC       1815
+#define OPT_MESS                        1818
+#define IDM_Engine1Options		1890
+#define IDM_Engine2Options		1891
 #define IDC_STATIC                      -1
 
 // Next default values for new objects
@@ -347,9 +515,9 @@
 #ifdef APSTUDIO_INVOKED
 #ifndef APSTUDIO_READONLY_SYMBOLS
 #define _APS_NO_MFC                     1
-#define _APS_NEXT_RESOURCE_VALUE        457
-#define _APS_NEXT_COMMAND_VALUE         1302
-#define _APS_NEXT_CONTROL_VALUE         1423
+#define _APS_NEXT_RESOURCE_VALUE        468
+#define _APS_NEXT_COMMAND_VALUE         1315
+#define _APS_NEXT_CONTROL_VALUE         1471
 #define _APS_NEXT_SYMED_VALUE           1404
 #endif
 #endif
