@@ -1,7 +1,7 @@
 /*
  * xoptions.c -- Move list window, part of X front end for XBoard
  *
- * Copyright 2000,2009 Free Software Foundation, Inc.
+ * Copyright 2000, 2009, 2010 Free Software Foundation, Inc.
  * ------------------------------------------------------------------------
  *
  * GNU XBoard is free software: you can redistribute it and/or modify
@@ -392,7 +392,7 @@ void TimeControlPopUp()
     XtSetArg(args[j], XtNright, XtChainRight);  j++;
     XtSetArg(args[j], XtNresizable, True);  j++;
     XtSetArg(args[j], XtNwidth,  85);  j++;
-//    XtSetArg(args[j], XtNheight, 20);  j++;
+    XtSetArg(args[j], XtNinsertPosition, 9999);  j++;
     tcTime = XtCreateManagedWidget("TC", asciiTextWidgetClass, form, args, j);
     XtAddEventHandler(tcTime, ButtonPressMask, False, SetFocus, (XtPointer) popup);
 
@@ -603,8 +603,8 @@ void EngineCallback(w, client_data, call_data)
 	// read all switches
 	appData.periodicUpdates = ReadToggle(w1);
 //	appData.hideThinkingFromHuman = ReadToggle(w2);
-	appData.firstScoreIsAbsolute  = ReadToggle(w3);
-	appData.secondScoreIsAbsolute = ReadToggle(w4);
+	first.scoreIsAbsolute  = appData.firstScoreIsAbsolute  = ReadToggle(w3);
+	second.scoreIsAbsolute = appData.secondScoreIsAbsolute = ReadToggle(w4);
 	appData.testClaims    = ReadToggle(w5);
 	appData.checkMates    = ReadToggle(w6);
 	appData.materialDraws = ReadToggle(w7);
@@ -762,7 +762,7 @@ void EnginePopUp()
     XtSetArg(args[j], XtNright, XtChainLeft);  j++;
     XtSetArg(args[j], XtNresizable, True);  j++;
     XtSetArg(args[j], XtNwidth,  60);  j++;
-//    XtSetArg(args[j], XtNheight, 20);  j++;
+    XtSetArg(args[j], XtNinsertPosition, 9999);  j++;
     engThreshold = XtCreateManagedWidget("Threshold", asciiTextWidgetClass, form, args, j);
     XtAddEventHandler(engThreshold, ButtonPressMask, False, SetFocus, (XtPointer) popup);
 
@@ -908,6 +908,7 @@ struct NewVarButton buttonDesc[] = {
     {N_("berolina"),          "#FFFFFF", 0, VariantBerolina},
     {N_("cylinder"),          "#FFFFFF", 0, VariantCylinder},
     {N_("shatranj"),          "#FFFFFF", 0, VariantShatranj},
+    {N_("makruk"),            "#FFFFFF", 0, VariantMakruk},
     {N_("atomic"),            "#FFFFFF", 0, VariantAtomic},
     {N_("two kings"),         "#FFFFFF", 0, VariantTwoKings},
     {N_("3-checks"),          "#FFFFFF", 0, Variant3Check},
@@ -1234,6 +1235,7 @@ void UciPopUp()
 	XtSetArg(args[j], XtNright, XtChainRight);  j++;
 	XtSetArg(args[j], XtNresizable, True);  j++;
 	XtSetArg(args[j], XtNwidth, i&1 ? 245 : 50); j++;
+	XtSetArg(args[j], XtNinsertPosition, 9999);  j++;
 	if(i&1) {
 	    XtSetArg(args[j], XtNstring, * (char**) controlDesc[i].ptr ? 
 					 * (char**) controlDesc[i].ptr : ""); j++;
@@ -1476,7 +1478,7 @@ void CreateComboPopup(parent, name, n, mb)
 void SettingsPopUp(ChessProgramState *cps)
 {
     Arg args[16];
-    Widget popup, layout, dialog, edit=NULL, form, oldform, last, b_ok, b_cancel, leftMargin = NULL;
+    Widget popup, layout, dialog, edit=NULL, form, oldform, last, b_ok, b_cancel, leftMargin = NULL, textField = NULL;
     Window root, child;
     int x, y, i, j, height, width, h, c;
     int win_x, win_y;
@@ -1533,9 +1535,10 @@ void SettingsPopUp(ChessProgramState *cps)
 	    XtSetArg(args[j], XtNright, XtChainRight);  j++;
 	    XtSetArg(args[j], XtNresizable, True);  j++;
 	    XtSetArg(args[j], XtNstring, cps->option[i].type==Spin ? def : cps->option[i].textValue);  j++;
+	    XtSetArg(args[j], XtNinsertPosition, 9999);  j++;
 	    edit = last;
 	    cps->option[i].handle = (void*)
-		(last = XtCreateManagedWidget("text", asciiTextWidgetClass, form, args, j));   
+		(textField = last = XtCreateManagedWidget("text", asciiTextWidgetClass, form, args, j));   
 	    XtAddEventHandler(last, ButtonPressMask, False, SetFocus, (XtPointer) popup);
 	    if(cps->option[i].type == TextBox) break;
 
@@ -1631,7 +1634,7 @@ void SettingsPopUp(ChessProgramState *cps)
     SettingsUp = True;
 
     previous = NULL;
-    if(edit)SetFocus(edit, popup, (XEvent*) NULL, False);
+    if(textField)SetFocus(textField, popup, (XEvent*) NULL, False);
 }
 
 void FirstSettingsProc(w, event, prms, nprms)
